[![License badge](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
### <h1 align="center" id="title">The Instructed Glacier Model (IGM) </h1>
 
 <div align="center">
    <img src="logo/logo_igm.svg" width="40%" alt="Alt text">
</div>

Source code of the Instructed Glacier Model (IGM).

Documentation (from version 3) : https://igm-model.org/

Documentation (up to version 2) : https://github.com/jouvetg/igm/wiki
